<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="所属车辆">
              <el-select clearable filterable style="width:100%" v-model="querys[0].value" placeholder="请选择所属车辆">
                <el-option v-for="item in vehicleIdSelectOptions" :key="item.value" :label="item.label"
                  :value="item.value"></el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="接收时间">
              <el-input clearable placeholder="请输入接收时间" v-model="querys[1].value" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索
            </el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增
        </el-button>
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除
          </el-button>
        </el-popconfirm>
      </div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>

        <el-table-column min-width="120" fixed prop="vehicleIdName" label="所属车辆"
          show-overflow-tooltip></el-table-column>

        <el-table-column fixed sortable prop="receiveTime" label="接收时间" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="accStatus" label="ACC状态">
          <template slot-scope="scope">
            {{
              scope.row.accStatus == null
                ? ''
                : scope.row.accStatus == '1'
                  ? '开启'
                  : '关闭'
            }}
          </template>
        </el-table-column>

        <el-table-column fixed prop="valid" label="GPS是否有效">
          <template slot-scope="scope">
            {{
              scope.row.valid == null
                ? ''
                : scope.row.valid == '1'
                  ? '是'
                  : '否'
            }}
          </template>
        </el-table-column>

        <el-table-column fixed prop="latitude" label="纬度" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="longitude" label="经度" show-overflow-tooltip></el-table-column>

        <el-table-column fixed prop="altitude" label="海拔高度" show-overflow-tooltip></el-table-column>

        <el-table-column fixed sortable prop="createTime" label="创建时间" show-overflow-tooltip></el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <CmgtDutyVehicleGpsinfoFormDialog ref="formModal"></CmgtDutyVehicleGpsinfoFormDialog>
  </div>
</template>

<script>
import { TableMixin } from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
import CmgtDutyVehicleGpsinfoApi from '@/views/Manage/duty/api/CmgtDutyVehicleGpsinfoApi'
import CmgtDutyVehicleGpsinfoFormDialog from '@/views/Manage/duty/components/CmgtDutyVehicleGpsinfoFormDialog'

export default {
  name: 'CmgtDutyVehicleGpsinfoManage',
  components: {
    CmgtDutyVehicleGpsinfoFormDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/cmgtDutyVehicleGpsinfo/delete'
      },
      vehicleIdSelectOptions: [],
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'vehicle_id_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'receive_time_',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false,
      fuelTypes: []
    }
  },
  created() {
    CommonApi.loadSelectOptions(
      { name: 'cmgtDutySelectOptions.getCmgtDutyVehicles' },
      res => {
        this.vehicleIdSelectOptions = res
      }
    )
  },
  mounted() {
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'create_time_'
        }
      ]
      this.queryParam.querys = []

      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      CmgtDutyVehicleGpsinfoApi.loadCmgtDutyVehicleGpsinfo(
        this.queryParam,
        res => {
          //console.log(res, 'res')
          this.total = res.total
          this.tableData = res.rows
          this.$set(this.tableData)
          this.loading = false
        }
      )
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    // 关联设备
    // handleClick(item) {
    //   console.log(item.id)
    //   this.StshowFormDias = true
    // },
    closeStshowForm() {
      this.StshowFormDias = false
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
